@@ -4,7 +4,7 @@ use Moo;
 
 ## no critic (TestingAndDebugging::ProhibitNoStrict)
 
-our $VERSION = '0.000025';
+our $VERSION = '0.000026';
 
 use App::perlimports::Sandbox ();
 use Class::Inspector          ();
@@ -12,7 +12,7 @@ use List::Util qw( any );
 use Module::Runtime qw( require_module );
 use Sub::HandlesVia;
 use Try::Tiny qw( catch try );
-use Types::Standard qw(ArrayRef Bool HashRef InstanceOf Str);
+use Types::Standard qw(ArrayRef Bool HashRef Int InstanceOf Str);
 
 with 'App::perlimports::Role::Logger';
 
@@ -185,6 +185,16 @@ has _pkg_for_implicit => (
     default => sub { return shift()->_random_pkg_name },
 );
 
+has success_counter => (
+    traits  => ['Counter'],
+    is      => 'ro',
+    isa     => Int,
+    default => 0,
+    handles => {
+        _increment_success_counter => 'inc',
+    },
+);
+
 has uses_moose => (
     is      => 'ro',
     isa     => Bool,
@@ -192,6 +202,14 @@ has uses_moose => (
     builder => '_build_uses_moose',
 );
 
+sub evals_ok {
+    my $self = shift;
+
+    $self->explicit_exports;
+    $self->implicit_exports;
+    return $self->success_counter;
+}
+
 sub _build_explicit_exports {
     my $self = shift;
 
@@ -379,6 +397,9 @@ EOF
         $logger_cb->($@);
         return undef, $@;
     }
+    else {
+        $self->_increment_success_counter;
+    }
 
     ## no critic (TestingAndDebugging::ProhibitNoStrict)
     no strict 'refs';
@@ -481,7 +502,7 @@ App::perlimports::ExportInspector - Inspect code for exportable symbols
 
 =head1 VERSION
 
-version 0.000025
+version 0.000026
 
 =head1 SYNOPSIS
 
@@ -530,6 +551,11 @@ In cases where we cannot be certain about the explicit exports, you can try to
 fall back to the implicit exports to get an idea of what this module can
 export.
 
+=head2 evals_ok
+
+Returns true if either implicit or explicit exports can be built without
+setting C<$@>.
+
 =head2 implicit_export_names_match_values
 
 Returns true if the keys and values in C<implicit_exports> match.
@@ -538,6 +564,11 @@ Returns true if the keys and values in C<implicit_exports> match.
 
 Returns true if the keys and values in C<explicit_exports> match.
 
+=head2 success_counter
+
+Returns an integer representing the number of times we were able to execute
+eval statements for this package which did not pollute C<$@>.
+
 =head1 CAVEATS
 
 This may not work with modules using some creative way of managing symbol
